ドキドメ！ | 初心者向けにドメイン取得からWordPressの始め方や使い方、基本的なカスタマイズまで図解で紹介します。
Description: 独自ドメインの取得からWordPressの設置、カスタマイズ、プラグインまでの記事をまとめてみましたので参考にしてみて下さい。初心者でも分かりやすいように図解で解説してます。また、「WordPress
Keywords: ドメイン取得,初心者,ワードプレス,twentytwelve, ロリポップ,

# WordPress設置とカスタマイズ、プラグインまとめ

独自ドメインの取得からWordPressの設置、カスタマイズ、プラグインまでの記事をまとめてみましたので参考にしてみて下さい。初心者でも分かりやすいように図解で解説してます。また、「WordPressの始め方」「カスタマイズ」「プラグイン」それぞれサイト上部のメニューバーでも分けてます。

## 独自ドメイン取得やサーバー契約の前準備編

- 独自ドメインのメリットとデメリット
- ドメイン取得やサーバーを借りる前に知っておく事
  - 楽天カードを作る前準備編
  - 楽天の無料会員登録の仕方と手順
  - 楽天カードの申し込みと入力内容
  - 楽天カード入会特典のポイントのもらい方
- おさいぽの登録と設定の仕方

## 独自ドメインを取得してサーバーの契約をする

- 独自ドメイン取得方法と手順を解説
- ロリポップのプランの比較と選び方
- ロリポップ申し込みの方法を図解で解説
- ロリポップに独自ドメインを設定する
- ムームードメインの自動更新設定方法
- ロリポップの自動更新設定の方法

## ロリポップでWordPressを簡単インストール

- ロリポップでMySQLデータベースの設定をする
- WordPressを簡単インストールする

## WordPressを始める前の基礎知識編

- WordPressのログイン方法を覚えておこう
- WordPressの基本用語を覚えておく
- 最初にWordPressの構造を見てみよう
- プラグインのインストールの仕方を覚えよう
- WordPressのバージョンを更新する手順

## 最初にしておくべきWordPressの初期設定

- 最初にするべきはWordPressのユーザー設定
- WordPressの一般設定をする
- パーマリンクの解説と設定方法
- WordPressのメディア設定の解説
- WordPressのディスカッション設定を解説
- 【重要】WordPressバックアップの方法と種類

## WordPress記事投稿の方法と基礎

- 記事投稿前の基礎知識編
- 記事投稿前にカテゴリーを作成してみる
- 記事投稿の基本的な流れと手順
- ビジュアルエディタの使い方と記事投稿方法
- WordPressでの画像挿入とアイキャッチの設定
- WordPressのメニューナビの使い方と設定
- WordPressのサイトを収益化する方法

## WordPressのカスタマイズの前にやっておく事

- 【重要】WordPressのテーマ選びの前に知っておく事
- カスタマイズの前にテーマの構成を把握しておく
- 子テーマを作り有効化する方法（ロリポップ版）
- エックスサーバーで子テーマを作成する方法
- ダウンロードしたテーマをwordpressのテーマに設定する方法
- 子テーマにfunctions.phpを追加する時の注意点

## TwentyTwelveカスタマイズ

- WordPressカテゴリーの未分類を削除する方法
- 文字のフォントや大きさ、行間をカスタマイズ
- TwentyTwelveタイトル全般のカスタマイズ
- WordPress見出しの使い方とカスタマイズ
- 記事内やサイドバーのリンクの色や装飾をカスタマイズ
- WordPressサイドバーのカスタマイズまとめ
- グローバルナビ（メニュー部分）のカスタマイズ
- TwentyTwelveの背景色を変更するカスタマイズ
- TwentyTwelveの「コメントをどうぞ」を移動もしくは削除する
- TwentyTwelveのヘッダー画像設定と位置変更
- TwentyTwelveの横幅やサイドバーの幅を変更する方法
- TwentyTwelveにパンくずリストを設置する方法
- WordPressコメント欄のカスタマイズ
- メタ情報「カテゴリー」や「投稿日」をカスタマイズ
- WordPress見出しの使い方とカスタマイズ
- 自分のサイトにファビコンを設置しよう
- アイキャッチ画像のサイズと位置のカスタマイズ
- トップページやカテゴリーページを抜粋記事の一覧表示にする
- TwentyTwelveに「続きを読む」を設置するカスタマイズ
- TwentyTwelveのアイキャッチ画像サイズをページごとに変える
- TwentyTwelveフッターの「Proudly powered by WordPress」をCopyrightに変更
- カテゴリー別アーカイブの表示をカスタマイズ
- WordPressのサイドバーに自作の人気記事一覧を表示させる方法
- WordPressで目次（記事一覧ページ）を作る方法
- 子テーマにfunctions.phpを追加する時の注意点
- スマートフォンページのフッターに固定メニューを作成してみました
- 固定ページと個別ページでサイドバーを使い分ける方法
- 関連記事をプラグインなしで表示させる方法（タグで関連付け）
- 関連記事をプラグインなしで表示させる方法（カテゴリーで関連付け）
- WordPressで画像配置の基本と横並びにする方法

## 便利なプラグイン一覧

- ユーザー名がバレるのを防ぐプラグイン【Edit Author Slug】
- スパムコメントを防ぐプラグイン【Akismet】の設定方法を解説
- WordPressのバックアッププラグイン【BackWPup】の設定方法
- 日本語化に対応するプラグイン 【WP Multibyte Patch】
- カテゴリーの順番を入れ替えるプラグイン【My Category Order】
- ソーシャルボタンを設置するプラグイン【WP Social Bookmarking Light】の設置と設定
- ページの先頭へスクロールしてくれるプラグイン【Scroll To Top】の設定
- リンク切れをお知らせしてくれるプラグイン【Broken Link Checker】
- 適切にping送信をしてくれるプラグイン【WordPress Ping Optimizer】
- 訪問者のニーズが分かるプラグイン【Search Meter】
- 人気記事一覧を簡単設置できるプラグイン【WordPress Popular Posts】
- よく使うタグを登録し簡単に挿入できるプラグイン【AddQuicktag】
- 全記事から文字列を検索し一括置換できるプラグイン【Search Regex】
- 関連記事を表示させるプラグイン【Yet Another Related Posts Plugin】の設定方法

## WordPressの高速化

- ブログの表示スピードを調べる方法
- 画像を一括で圧縮できるプラグイン「EWWW Image Optimizer」で高速化
- キャッシュを利用してWordPress高速化する仕組み
- 「ブラウザのキャッシュを活用する」に対策してみた
- CSSファイルをまとめて圧縮して高速化
- プラグインで追加されたCSSを１つにまとめてWordPressを高速化
- レンダリングをブロックしている JavaScriptをフッターに移動させる
- jQuery本体をCDNに置き換えて高速化
- プラグインで追加されるJavaScriptやCSSのハンドル名を調べる方法
- アイコン画像をWebフォントに変更して高速化
- ソーシャルボタンを自作してWordPressの高速化
- 自作のJavaScriptをWordPressで利用する方法
- ページの先頭に戻るボタンを自作してみた

## WordPressでの集客方法

- WordPressのサイトを収益化する方法
- WordPressで集客するための7つのコツ
- 検索上位表示で集客する基本

#### こちらの記事もおすすめです

サイトで稼ぐ方法

最近はブログを収益化して稼ぐ方も多くなってきました。せっかくブログやサイトを作成するのであれば収益化できたらいいですよね！でも何から始めたらいいのか分からないという方も多いと思いますので、基本的なやり方や稼ぐ方法も知っておきましょう。
⇒WordPressのサイトを収益化する方法

無料のセミナー

お金に関するテーマは非常に需要のあるテーマの１つなので集客しやすい分野です。家計の節約、ネットでの収益などはこれからも益々関心の高まる分野ですし、セミナーなどの情報や体験談などは初心者でもネタにする事ができます。

特にブログのネタに困っている人などはブログの幅を広げるチャンスにもなるし、モチベーションアップにも最適。最近はお金に関する無料のセミナーなどもあるので一度参加してみる事をおすすめします。
⇒お金の教養無料セミナー

サイトのアクセスアップや収益化におすすめの無料レポート

- facebook 37
- tweet
- Google+ 1
- はてブ 9
- LINE
- Pocket 26
- RSS
- feedly 11

#### ↓↓ブログの更新はこちらから

> ドキドメ！

@sigezo150さんのツイート

## 「WordPress設置とカスタマイズ、プラグインまとめ」への102件のフィードバック

### コメントをどうぞ コメントをキャンセル

名前

コメント

内容に問題なければ、下記の「コメントを送信する」ボタンを押してください。

1. りた 2015年11月23日 8:45 PM

   しげぞう様

   ご返信遅くなり、大変申し訳ございません。また、アドバイスして頂き、誠にありがとうございます。

   しげぞう様のアドバイス、非常に身にしみました。最近他のブロガーさんと比較しがちで、アクセス数ばかりに目を向けていました。そして、いつの間にかSEO至上主義者になっていました。

   本来のブログ開設の目的だった【読者のため】が、今では【アクセス数のため＝自分のため】になりかけており、非常に反省している次第です。今は冷静になり、初心に戻って、読者のためになる記事を更新し続けることにしました。

   本当にしげぞう様に相談して良かったです。私にとって、ブロガーとの交流（これを交流というのは可笑しいかもしれませんが笑）はしげぞう様だけであり、ブログ開設後もここまで手厚くアドバイスして頂けることに感謝してもしきれません。

   まだまだブログヒヨっ子でつまらない質問をするかもしれません。その際は、何卒宜しくお願い致します。

   そして、これからもブログ運営頑張って行きます！！！温かい目で見守って頂けたら幸いです。

2. しげぞう 投稿作成者2015年11月22日 10:07 PM

   りた様

   返信ありがとうございます。NEVERまとめは私も利用していて、自分のサイトを紹介するようなまとめも作っておりますが、これが大きな効果になっている訳ではありません。自作自演なんですが、これはある意味リスキーな部分もありますので、他の方におすすめするような事ではないと自分で思っております。

   ただ、NEVERまとめから被リンクが付くので多少は効果があるかもしれませんが、自作自演はできれば辞めておき、別の方法を考えた方が良いかもしれません。りた様のブログも開設されてまだ数ヶ月かと思いますが、もうしばらく記事を書きながら様子を見ると良いと思います。

   何もせずに様子を見るのではなく、Search Consoleでどのような検索ワードで上位表示されているのか？とかどれくらいの表示回数があるのか？などを調べて新しいキーワードや更に深く掘り下げるキーワードを探してみるのも良いかもしれません。

   半年程度が過ぎてから一気に色々なキーワードが上位に行くような場合も多々ありますし、私も諦めて別のサイトを作っている間にいつの間にか上位表示されていたなんて事が多いのです。ある程度記事数があればある日突然順位が上がるような事があります。

   SEOを考え始めるとどうしても空回りすることが多くなります。●●の対策をしてみたけど、逆に順位が下がった、それで元に戻しても順位が戻らないので、別の対策をした・・・というような作業が増えてしまいます。効果がでるのに時間がかかるのですが、それを待ちきれないとか自分がした対策を信じきれずに別の対策をしてしまうという循環は悪循環になる場合が多いですので注意が必要かと思います。

3. りた 2015年11月22日 11:25 AM

   しげぞう様

   りたです。いつもお世話になっております。
   今回はNEVERまとめについて、質問させて頂きたくご連絡差し上げました。

   最近アクセス数やユーザー数が頭打ちになっており、悩んでおります。最近痛感していることはSEOの弱さです。

   私が先に記事を書いたとしても、はてなブログなどの方が遅く書いても検索順で下位につくことが多く、対策せねばと考えている次第です。

   個人的には読者のために書いているので、見ている人が増えてほしいのが本音です。

   そこで、NEVERまとめ記事を作成して、自分のブログ記事を添付してアクセス数を増やすことを考えているのですが、どうでしょうか？ド素人で不安になり、しげぞう様に相談しようと思い、連絡しました笑

   アドバイス等、頂ければ幸いです。

   よろしくお願いします。

4. しげぞう 投稿作成者2015年11月18日 1:16 PM

   りた様

   返信ありがとうございます。無事に装飾もできたようで良かったです。りた様のブログは非常に濃い内容になっていて、しかもまだ定期的に更新されているので本当に凄いと思います。また社会人用のブログを作成されるという事ですのでまた教えて頂けると嬉しいです。今後もよろしくお願い致します。

5. りた 2015年11月18日 12:14 PM

   しげぞう様

   ご返信、誠にありがとうございます。無事、装飾することができました！てっきり、初期状態ですでに装飾済みかと思っていました。
   ご迷惑お掛けしました。

   実は、来年から社会人用のブログを作成しようと考えておりますので、再びしげぞう様のブログを勉強させて頂きます。またお世話になると思いますが、ご容赦下さい笑

   今後もご迷惑お掛けしますが、何卒宜しくお願い致します！

6. しげぞう 投稿作成者2015年11月18日 10:43 AM

   りた様

   お久しぶりです！アクセス数や広告費が伸びているようで私も嬉しいです！引用の箇所なんですが、コメントのコードの部分が反映されていないので、推測なんですが、おそらく「blockquote」タグの事かなと思います。これはスタイルシートで書体や色、文字の大きさなどの変更をする事ができます。デフォルトの初期状態だと装飾的な要素がほとんどないと思いますので、これはスタイルシートで装飾して試してみると良いかと思います。

   私のブログの記事に引用タグの装飾の記事は書いていなかったのですが、「引用タグ　装飾」とか「引用タグ　CSS」などで検索するとコピペできるようなサンプルがたくさん見つかると思いますので、一度検索して試して見てください。

   余談ですが、毎月のアクセス公開楽しみにしております。今後もよろしくお願い致します。

### サイト内検索

検索:

### カテゴリー

- 最初に必要な基礎知識
  - 楽天カード作成
- ドメイン取得
- サーバーの契約と設定
- WordPressの基礎知識編
- WordPressの設定
- 記事作成
- WordPressカスタマイズ
- プラグイン
- WordPressの集客方法
- WordPress高速化
- WordPressのエラー対処方法

### 人気記事一覧

- 楽天カードの申し込み方法と入力内容
- WordPress見出しの使い方とカスタマイズ
- 楽天カード入会特典のポイントのもらい方
- 子テーマを作り有効化する方法
- WordPressコメント欄のカスタマイズ
- 文字のフォントや大きさ、行間をカスタマイズ
- 独自ドメインの取得方法と手順を解説
- TwentyTwelveフッターの「Proudly powered by WordPress」をCopyrightに変更
- TwentyTwelveの横幅やサイドバーの幅を変更する方法
- ロリポップのプランの比較と選び方

### 最近の投稿

- スマートフォンページのフッターに固定メニューを作成してみました
- WordPressのヘッダーに検索フォームを設置する方法
- ダウンロードしたテーマをwordpressのテーマに設定する方法
- WordPress高速化まとめページ
- HTMLとCSS、JavaScriptを縮小し最適化するプラグイン【Autoptimize】

### 最近のコメント

- Loading...

▲TOP